==> haskell-mueval-0.9.4-61-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mueval.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mueval
version:              0.9.4
visibility:           public
id:                   mueval-0.9.4-2WwSbxGSjF99u0MmeEf0w
key:                  mueval-0.9.4-2WwSbxGSjF99u0MmeEf0w
license:              BSD-3-Clause
maintainer:           Terence Ng <stoicism03@gmail.com>
author:               Gwern <gwern@gwern.net>
homepage:             https://github.com/TerenceNg03/mueval#readme
synopsis:             Safely evaluate pure Haskell expressions
description:
    Mueval is a Haskell interpreter. It uses the GHC API to evaluate arbitrary Haskell expressions. Importantly, mueval takes many precautions to defang and avoid \"evil\" code.  It uses resource limits, whitelisted modules and Safe Haskell, special Show instances for IO, threads, processes, and changes of directory to sandbox the Haskell code. . It is, in short, intended to be a standalone version of Lambdabot'\''s famous evaluation functionality. For examples and explanations, please see the README file. . Mueval is POSIX-only.

category:             Development, Language
abi:                  8fa3d0cb8b9ceb545347e54f273f9e8a
exposed:              True
exposed-modules:
    Mueval.ArgsParse Mueval.Context Mueval.Interpreter Mueval.Parallel
    Mueval.Resources

hidden-modules:       Paths_mueval
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mueval
hs-libraries:         HSmueval-0.9.4-2WwSbxGSjF99u0MmeEf0w
depends:
    Cabal-3.8.1.0 QuickCheck-2.15.0.1-Fs5gw6qOmgJQY49llBRf6
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    filepath-1.4.2.2 hint-0.9.0.8-4bzCs0L8a2y1YyKIH5fOJI mtl-2.2.2
    process-1.6.18.0 show-0.6-AemCQvOWwKZ3c8yvLHcy6Z
    simple-reflect-0.3.3-Kct69QODYQA4F7issyqpIH unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-mueval/html/mueval.haddock
haddock-html:         /usr/share/doc/haskell-mueval/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mueval-0.9.4-80-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mueval.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mueval
version:              0.9.4
visibility:           public
id:                   mueval-0.9.4-3UcYAUgbmTyDncq539h1Sw
key:                  mueval-0.9.4-3UcYAUgbmTyDncq539h1Sw
license:              BSD-3-Clause
maintainer:           Terence Ng <stoicism03@gmail.com>
author:               Gwern <gwern@gwern.net>
homepage:             https://github.com/TerenceNg03/mueval#readme
synopsis:             Safely evaluate pure Haskell expressions
description:
    Mueval is a Haskell interpreter. It uses the GHC API to evaluate arbitrary Haskell expressions. Importantly, mueval takes many precautions to defang and avoid \"evil\" code.  It uses resource limits, whitelisted modules and Safe Haskell, special Show instances for IO, threads, processes, and changes of directory to sandbox the Haskell code. . It is, in short, intended to be a standalone version of Lambdabot'\''s famous evaluation functionality. For examples and explanations, please see the README file. . Mueval is POSIX-only.

category:             Development, Language
abi:                  c3911c629674674c55d9987534fa47fc
exposed:              True
exposed-modules:
    Mueval.ArgsParse Mueval.Context Mueval.Interpreter Mueval.Parallel
    Mueval.Resources

hidden-modules:       Paths_mueval
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mueval-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mueval
hs-libraries:         HSmueval-0.9.4-3UcYAUgbmTyDncq539h1Sw
depends:
    Cabal-3.8.1.0 QuickCheck-2.15.0.1-5wgMd498nCWIkHPGslLJlo
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    filepath-1.4.2.2 hint-0.9.0.8-3x8RVjeWbJJJVRjHI7qg58 mtl-2.2.2
    process-1.6.18.0 show-0.6-Eoa7tD6468C1lLqJildDmu
    simple-reflect-0.3.3-Kct69QODYQA4F7issyqpIH unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-mueval/html/mueval.haddock
haddock-html:         /usr/share/doc/haskell-mueval/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
